@@ -112,7 +112,7 @@ class LibFFI(ModuleBuilder):
 
     @property
     def version(self):
-        return self.cfg_version("3.4.2")
+        return self.cfg_version("3.4.4")
 
     def _do_linux_compile(self):
         self.run_configure(
@@ -264,7 +264,11 @@ class Sqlite(ModuleBuilder):
 
     @property
     def version(self):
-        return self.cfg_version("3.38.5")
+        if PPG.target.is_macos and PPG.target.arch == "x86_64":
+            # Weird C compilation error on Intel macs with py3.11, not sure what that is about, sticking to older sqlite for now...
+            return self.cfg_version("3.38.5")
+
+        return self.cfg_version("3.39.4")
 
     def _do_linux_compile(self):
         self.run_configure(
@@ -314,7 +318,7 @@ class Xz(ModuleBuilder):
 
     @property
     def version(self):
-        return self.cfg_version("5.2.5")
+        return self.cfg_version("5.2.7")
 
     def _do_linux_compile(self):
         self.run_configure(
@@ -347,7 +351,7 @@ class Zlib(ModuleBuilder):
 
     @property
     def version(self):
-        return self.cfg_version("1.2.12")
+        return self.cfg_version("1.2.13")
 
     def _do_linux_compile(self):
         self.run_configure("./configure", "--static")
